fireworks.utilities.tests package — FireWorks 2.0.4 documentation

# fireworks.utilities.tests package

## Submodules

## fireworks.utilities.tests.test_dagflow module

Unit tests for the DAGFlow class.

class fireworks.utilities.tests.test_dagflow.DAGFlowTest(methodName='runTest')

  Bases: `TestCase`

  run tests for DAGFlow class.

  setUp() → None

    Hook method for setting up the test fixture before exercising it.

  test_dagflow_clashing_inputs() → None

    Parent firework output overwrites an input in spec.

  test_dagflow_clashing_outputs() → None

    Subsequent task overwrites output of a task.

  test_dagflow_cut() → None

    Disconnected graph.

  test_dagflow_link() → None

    Wrong links.

  test_dagflow_loop() → None

    Loop in graph.

  test_dagflow_missing_input() → None

    Missing input.

  test_dagflow_non_dataflow_tasks() → None

    non-dataflow tasks using outputs and inputs keys do not fail.

  test_dagflow_ok() → None

    Construct and replicate.

  test_dagflow_race_condition() → None

    Two parent firework outputs overwrite each other.

  test_dagflow_view() → None

    Visualize the workflow graph.

## fireworks.utilities.tests.test_filepad module

class fireworks.utilities.tests.test_filepad.FilePadTest(methodName='runTest')

  Bases: `TestCase`

  setUp() → None

    Hook method for setting up the test fixture before exercising it.

  tearDown() → None

    Hook method for deconstructing the test fixture after testing it.

  test_add_file() → None
  test_add_file_with_no_identifier() → None
  test_delete_file() → None
  test_get_file() → None
  test_update_file() → None
  test_update_file_by_id() → None

## fireworks.utilities.tests.test_fw_serializers module

class fireworks.utilities.tests.test_fw_serializers.ExplicitSerializationTest(methodName='runTest')

  Bases: `TestCase`

  setUp() → None

    Hook method for setting up the test fixture before exercising it.

  test_explicit_serialization() → None

class fireworks.utilities.tests.test_fw_serializers.ExplicitTestSerializer(a)

  Bases: `FWSerializable`

  __init__(a) → None
  classmethod from_dict(m_dict)
  to_dict()

class fireworks.utilities.tests.test_fw_serializers.SerializationTest(methodName='runTest')

  Bases: `TestCase`

  setUp() → None

    Hook method for setting up the test fixture before exercising it.

  tearDown() → None

    Hook method for deconstructing the test fixture after testing it.

  test_as_dict() → None
  test_complex_json() → None
  test_complex_yaml() → None
  test_implicit_serialization() → None
  test_json() → None
  test_numpy_array() → None
  test_sanity() → None
  test_serialize_fw_decorator() → None
  test_unicode_json() → None
  test_unicode_json_file() → None
  test_unicode_yaml() → None
  test_unicode_yaml_file() → None
  test_yaml() → None

## fireworks.utilities.tests.test_update_collection module

class fireworks.utilities.tests.test_update_collection.UpdateCollectionTests(methodName='runTest')

  Bases: `TestCase`

  classmethod setUpClass() → None

    Hook method for setting up class fixture before running tests in the class.

  classmethod tearDownClass() → None

    Hook method for deconstructing the class fixture after running all tests in the class.

  test_update_path() → None

## fireworks.utilities.tests.test_visualize module

fireworks.utilities.tests.test_visualize.power_wf()

fireworks.utilities.tests.test_visualize.test_plot_wf(power_wf) → None

fireworks.utilities.tests.test_visualize.test_wf_to_graph(power_wf) → None

## Module contents